@@ -1,15 +1,13 @@
-# $Id: ImageClip.pm,v 1.14 2004/04/11 23:36:20 joern Exp $
+# $Id: ImageClip.pm,v 1.7 2001/11/23 20:21:51 joern Exp $
 
 #-----------------------------------------------------------------------
-# Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
-# All Rights Reserved. See file COPYRIGHT for details.
+# Copyright (C) 2001 Jrn Reder <joern@zyn.de> All Rights Reserved
 # 
 # This module is part of Video::DVDRip, which is free software; you can
 # redistribute it and/or modify it under the same terms as Perl itself.
 #-----------------------------------------------------------------------
 
 package Video::DVDRip::GUI::ImageClip;
-use Locale::TextDomain qw (video.dvdrip);
 
 use Gtk::Gdk::Pixbuf;
 
@@ -60,8 +58,8 @@ sub new {
 	my %par = @_;
 	my  ($gtk_window, $filename, $width, $height, $thumbnail) =
 	@par{'gtk_window','filename','width','height','thumbnail'};
-	my  ($changed_callback, $no_clip, $show_tooltips) =
-	@par{'changed_callback','no_clip','show_tooltips'};
+	my  ($changed_callback, $no_clip) =
+	@par{'changed_callback','no_clip'};
 
 	my $drawing_area = Gtk::DrawingArea->new;
 	my $event_box = Gtk::EventBox->new;
@@ -82,7 +80,7 @@ sub new {
 		clip_right       => 16,
 		knob_size        => 11,
 		knobs            => {},
-		grid             => 2,
+		grid             => 4,
 	}, $type;
 
 	if ( $filename ) {
@@ -99,13 +97,6 @@ sub new {
 	$event_box->show;
 	$event_box->add ($drawing_area);
 	
-	if ( $show_tooltips ) {
-		my $tooltip = Gtk::Tooltips->new;
-		$tooltip->set_tip ($event_box, __"Click on the image to open a window");
-		$tooltip->enable;
-		$tooltip->set_delay(0);
-	}
-
 	if ( not $thumbnail ) {
 		$event_box->set_events( 'button_press_mask' );
 		$event_box->signal_connect (
